Parse the ~/.local/share/recently-used.xbel file
fn main() -> Result<(), Box<dyn std::error::Error>> {
let recently_used = recently_used_xbel::parse_file()?;
for bookmark in recently_used.bookmarks {
println!("{:?}", bookmark);
}
Ok(())
}Structs
- Application
- An application that accessed the bookmark.
- Applications
- A list of applications that accessed the bookmark.
- Bookmark
- A file that was recently opened by the desktop user.
- Info
- Metadata
- Metadata containing MIME type and application info.
- Mime
Type - The MIME type of the file.
- Recently
Used - Stores recently-opened files accessed by the desktop user.
Enums
- Error
- An error that can occur when accessing recently-used files.
Functions
- clear_
recently_ used - Clear the list of recently used files.
- dir
- The path where the recently-used.xbel file is expected to be found.
- parse_
file - Convenience function for parsing the recently-used.xbel file in its default location.
- remove_
recently_ used - Removes elements from the list of recently used files.
- update_
recently_ used - Updates the list of recently used files.